This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Spelling patch: gcc/cp


The following patch fixes various spelling errors in gcc/cp.  Applied to
mainline.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog,v
retrieving revision 1.2600
diff -u -r1.2600 ChangeLog
--- ChangeLog	2001/12/15 20:06:11	1.2600
+++ ChangeLog	2001/12/16 16:02:43
@@ -1,3 +1,9 @@
+2001-12-16  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+	* ChangeLog.1, ChangeLog.2, ChangeLog, NEWS, call.c, class.c,
+	cp-tree.h, decl.c, decl2.c, except.c, operators.def, optimize.c,
+	pt.c, rtti.c, semantics.c, typeck.c: Fix spelling errors.
+
 2001-12-15  Joseph S. Myers  <jsm28@cam.ac.uk>
 
 	* lang-options.h: Use American spelling in messages.
@@ -1308,7 +1314,7 @@
 2001-07-20  Nathan Sidwell  <nathan@codesourcery.com>
 
 	Remove old-abi remnants. Remove comments about old abi
-	behaviour. Remove refences to 'new-abi' in comments.
+	behaviour. Remove references to 'new-abi' in comments.
 	* cp-tree.h: Adjust comments.
 	(vbase_offsets_in_vtable_p): Delete.
 	(vcall_offsets_in_vtable_p): Delete.
@@ -3652,7 +3658,7 @@
 
 	* decl.c (struct binding_level): Adjust class_shadowed comments
 	to reflect reality.
-	(push_class_level_binding): Ajust comments to reflect reality.
+	(push_class_level_binding): Adjust comments to reflect reality.
 	Set IDENTIFIER_CLASS_VALUE when replacing an existing binding.
 	Don't set TREE_VALUE on the class_shadowed list.
 
@@ -6406,7 +6412,7 @@
 2000-06-23  Kriang Lerdsuwanakij <lerdsuwa@scf.usc.edu>
 
 	* parse.y (template_arg): Convert TEMPLATE_DECL
-	that is a template template paramter to
+	that is a template template parameter to
 	TEMPLATE_TEMPLATE_PARM here.
 
 	* cp-tree.def (TEMPLATE_TEMPLATE_PARM): Adjust comment.
@@ -7471,10 +7477,10 @@
 	* tinfo.h (__user_type_info::contained_virtual_p): New
 	predicate.
 	* tinfo.cc (__user_type_info::do_upcast): Fix bug with diamond
-	shaped heirarchy.
+	shaped hierarchy.
 	(__vmi_class_type_info::__do_upcast): Fix bug with NULL pointer to
-	diamond shaped heirarchy. Add early out for mixed diamond and
-	duplicate shaped heirarchy.
+	diamond shaped hierarchy. Add early out for mixed diamond and
+	duplicate shaped hierarchy.
 
 2000-05-24  Mark Mitchell  <mark@codesourcery.com>
 
@@ -7519,7 +7525,7 @@
 	(__si_class_type_info::__do_upcast): Adjust. Use parent's
 	__do_upcast.
 	(__vmi_class_type_info::__do_upcast): Likewise. Fix private
-	virtual base in diamond heirarchy bug.
+	virtual base in diamond hierarchy bug.
 
 2000-05-23  Mark Mitchell  <mark@codesourcery.com>
 
@@ -10559,7 +10565,7 @@
 	build_static_cast, build_reinterpret_cast, build_const_cast,
 	build_c_cast, build_modify_expr, get_delta_difference,
 	build_ptrmemfunc, check_return_expr): Replace 'ANSI C++' with
-	'ISO C++'.  Fusion consecutive calls to diagnotic message routines
+	'ISO C++'.  Fusion consecutive calls to diagnostic message routines
 	into a single one.
 	* typeck2.c (readonly_error, abstract_virtuals_error,
 	process_init_constructor, check_for_new_type): Likewise.
Index: ChangeLog.1
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog.1,v
retrieving revision 1.5
diff -u -r1.5 ChangeLog.1
--- ChangeLog.1	2001/10/28 19:24:59	1.5
+++ ChangeLog.1	2001/12/16 16:02:44
@@ -2309,7 +2309,7 @@
 	function.
 
 	Make base initialization more re-entrant so that synthesis on the
-	fly will work (and, eventually, template instantation on the fly).
+	fly will work (and, eventually, template instantiation on the fly).
 	* init.c (sort_member_init): Don't bother with members that can't be
 	initialized.  Reorganize a bit.  Don't initialize base members here.
 	(sort_base_init): New function, like sort_member_init, but for base
Index: ChangeLog.2
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog.2,v
retrieving revision 1.2
diff -u -r1.2 ChangeLog.2
--- ChangeLog.2	2001/10/28 19:24:59	1.2
+++ ChangeLog.2	2001/12/16 16:02:49
@@ -1216,7 +1216,7 @@
 1999-10-07  Mark Mitchell  <mark@codesourcery.com>
 
 	* pt.c (tsubst_expr): Set DECL_TEMPLATE_INSTANTIATED for a catch
-	paramter.
+	parameter.
 	
 	* semantics.c (expand_stmt): Don't pretend to have asmspecs for
 	local statics if we don't really have them.
@@ -1357,7 +1357,7 @@
 	(mark_lang_function): Use mark_stmt_tree.
 	* expr.c (cplus_expand_expr): Don't handle VEC_INIT_EXPR.
 	* init.c (build_new_1): Remove creation of VEC_INIT_EXPR.
-	(build_vec_init): Remove creation of stand-in intializer.
+	(build_vec_init): Remove creation of stand-in initializer.
 	* pt.c (begin_tree): Remove.
 	(end_tree): Likewise.
 	* semantics.c (SET_LAST_STMT): New macro.  Use it throughout.
@@ -1463,7 +1463,7 @@
 	(pushlevel_class): Don't push_decl_level.
 	(poplevel_class): Don't pop_stack_level.
 	(push_class_level_binding): Don't push_cache_obstack.
-	(init_decl_processing): Don't intialize decl_obstack.
+	(init_decl_processing): Don't initialize decl_obstack.
 	* search.c (push_class_decls): Don't push_cache_obstack.
 	* tree.c (list_hash_add): Put hash node on permanent_obstack.
 	(hash_tree_cons): Don't mess with obstacks.
@@ -2255,7 +2255,7 @@
 	if appropriate.
 	(finish_decl_cleanup): New function.
 	(expand_stmt): Use emit_local_var to output variables.		
-	(expand_body): Set current_funtion_name_declared.
+	(expand_body): Set current_function_name_declared.
 	
 1999-09-10  Mark Mitchell  <mark@codesourcery.com>
 
@@ -4139,7 +4139,7 @@
 	(ARITHMETIC_TYPE_P): Adjust definition for standard conformance.
 	(strip_top_quals): Declare.
 	(ncp_convert): Likewise.
-	(type_after_usual_arithmetic_converions): Likewise.
+	(type_after_usual_arithmetic_conversions): Likewise.
 	(composite_pointer_type): Likewise.
 	* call.c (strip_top_quals): Don't make it static.
 	(promoted_arithmetic_type_p): New function.
@@ -4670,7 +4670,7 @@
 1999-05-25  Mark Mitchell  <mark@codesourcery.com>
 
 	* class.c (finish_vtbls): Copy BINFO_VIRTUALs before using it to
-	intialize a vtable.
+	initialize a vtable.
 
 	* cp-tree.h (NAMESPACE_LEVEL): Reformat.
 	(lang_decl_flags): Document MEMFUNC_POINTER_TO.  Save four bytes
@@ -9673,7 +9673,7 @@
 	push_template_decl_real instead of push_template_decl.
 	* method.c (build_decl_overload_real): Remove prototype.  Give it
 	external linkage.
-	(build_overload_identififer): Adjust call to innermost_args.
+	(build_overload_identifier): Adjust call to innermost_args.
 	(build_template_decl_overload): Remove.
 	(set_mangled_name_for_decl): New function.
 	* parse.y (.finish_template_type): New non-terminal.
Index: NEWS
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/NEWS,v
retrieving revision 1.29
diff -u -r1.29 NEWS
--- NEWS	2001/08/02 10:51:15	1.29
+++ NEWS	2001/12/16 16:02:49
@@ -33,7 +33,7 @@
       void operator delete[] (void *);
     };
 
-  does not cause unncessary storage to be allocated when an array of
+  does not cause unnecessary storage to be allocated when an array of
   `A' objects is allocated.
 
   This change will only affect code that declares both of these
Index: call.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/call.c,v
retrieving revision 1.295
diff -u -r1.295 call.c
--- call.c	2001/12/13 01:37:46	1.295
+++ call.c	2001/12/16 16:02:50
@@ -1125,7 +1125,7 @@
     {
       /* [dcl.init.ref]
 
-	 If the intializer expression 
+	 If the initializer expression 
 	 
 	 -- is an lvalue (but not an lvalue for a bit-field), and "cv1 T1"
 	    is reference-compatible with "cv2 T2,"
Index: decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/decl.c,v
retrieving revision 1.841
diff -u -r1.841 decl.c
--- decl.c	2001/12/14 03:01:57	1.841
+++ decl.c	2001/12/16 16:02:54
@@ -7834,7 +7834,7 @@
   defer_p = DECL_FUNCTION_SCOPE_P (decl) || DECL_VIRTUAL_P (decl);
 
   /* We try to defer namespace-scope static constants so that they are
-     not emitted into the object file unncessarily.  */
+     not emitted into the object file unnecessarily.  */
   if (!DECL_VIRTUAL_P (decl)
       && TREE_READONLY (decl)
       && DECL_INITIAL (decl) != NULL_TREE
@@ -8401,7 +8401,7 @@
   DECL_ARTIFICIAL (fndecl) = 1;
   /* Make the function `inline' so that it is only emitted if it is
      actually needed.  It is unlikely that it will be inlined, since
-     it is only called via a function pointer, but we avoid unncessary
+     it is only called via a function pointer, but we avoid unnecessary
      emissions this way.  */
   DECL_INLINE (fndecl) = 1;
   /* Build the parameter.  */
@@ -11042,7 +11042,7 @@
       && TREE_OVERFLOW (TYPE_SIZE (type)))
     {
       error ("size of array `%s' is too large", name);
-      /* If we proceed with the array type as it is, we'll eventully
+      /* If we proceed with the array type as it is, we'll eventually
 	 crash in tree_low_cst().  */
       type = error_mark_node;
     }
Index: decl2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/decl2.c,v
retrieving revision 1.502
diff -u -r1.502 decl2.c
--- decl2.c	2001/12/09 16:33:42	1.502
+++ decl2.c	2001/12/16 16:02:54
@@ -1690,7 +1690,7 @@
      check here.  */
   if (TREE_CODE (value) == FUNCTION_DECL)
     {
-      cp_error ("cannot declare bitfield `%D' with funcion type",
+      cp_error ("cannot declare bitfield `%D' with function type",
 		DECL_NAME (value));
       return NULL_TREE;
     }
Index: except.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/except.c,v
retrieving revision 1.138
diff -u -r1.138 except.c
--- except.c	2001/12/02 00:04:35	1.138
+++ except.c	2001/12/16 16:02:54
@@ -86,7 +86,7 @@
 }
 
 /* Returns an expression to be executed if an unhandled exception is
-   propogated out of a cleanup region.  */
+   propagated out of a cleanup region.  */
 
 static tree
 cp_protect_cleanup_actions ()
Index: operators.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/operators.def,v
retrieving revision 1.8
diff -u -r1.8 operators.def
--- operators.def	2001/11/18 06:24:43	1.8
+++ operators.def	2001/12/16 16:02:54
@@ -29,7 +29,7 @@
    NAME
 
      The name of the operator, as a C string, but without the
-     preceeding `operator'.  This is the name that would be given in
+     preceding `operator'.  This is the name that would be given in
      the source program.  For `operator +', for example, this would be
      `+'.
    
@@ -48,7 +48,7 @@
 
    OLD_MANGLING
 
-     Analagous, but for the old ABI.
+     Analogous, but for the old ABI.
 
    ARITY
    
@@ -65,7 +65,7 @@
 
    There is code (such as in grok_op_properties) that depends on the
    order the operators are presented in this file.  In particular,
-   unary operators must preceed binary operators.  */
+   unary operators must precede binary operators.  */
  
 /* Use DEF_SIMPLE_OPERATOR to define a non-assignment operator.  Its
    arguments are as for DEF_OPERATOR, but there is no need to provide
Index: optimize.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/optimize.c,v
retrieving revision 1.80
diff -u -r1.80 optimize.c
--- optimize.c	2001/12/13 15:06:42	1.80
+++ optimize.c	2001/12/16 16:02:55
@@ -194,7 +194,7 @@
       for (; parm;
 	   parm = TREE_CHAIN (parm), clone_parm = TREE_CHAIN (clone_parm))
 	{
-	  /* Update this paramter.  */
+	  /* Update this parameter.  */
 	  update_cloned_parm (parm, clone_parm);
 	  /* We should only give unused information for one clone. */
 	  if (!first)
Index: pt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/pt.c,v
retrieving revision 1.563
diff -u -r1.563 pt.c
--- pt.c	2001/12/14 03:01:59	1.563
+++ pt.c	2001/12/16 16:02:55
@@ -9622,7 +9622,7 @@
 
          If CLASSTYPE_INTERFACE_ONLY, then the first explicit instantiation
 	 was `extern'.  If EXTERN_P then the second is.  If -frepo, chances
-	 are we already got marked as an explicit instantion because of the
+	 are we already got marked as an explicit instantiation because of the
 	 repo file.  All these cases are OK.  */
       if (!CLASSTYPE_INTERFACE_ONLY (t) && !extern_p && !flag_use_repository
 	  && complain)
Index: rtti.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/rtti.c,v
retrieving revision 1.127
diff -u -r1.127 rtti.c
--- rtti.c	2001/12/05 23:48:18	1.127
+++ rtti.c	2001/12/16 16:02:56
@@ -860,7 +860,7 @@
   return NULL_TREE;
 }
 
-/* Determine the hint flags describing the features of a class's heirarchy.  */
+/* Determine the hint flags describing the features of a class's hierarchy.  */
 
 static int
 class_hint_flags (type)
@@ -1315,7 +1315,7 @@
     TYPE_HAS_CONSTRUCTOR (base_desc_type_node) = 1;
   }
   
-  /* General heirarchy is created as necessary in this vector. */
+  /* General hierarchy is created as necessary in this vector. */
   vmi_class_desc_type_node = make_tree_vec (10);
   
   /* Pointer type_info. Adds two fields, qualification mask
Index: semantics.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/semantics.c,v
retrieving revision 1.237
diff -u -r1.237 semantics.c
--- semantics.c	2001/12/14 03:01:59	1.237
+++ semantics.c	2001/12/16 16:02:56
@@ -1116,7 +1116,7 @@
 	  /* We're running through the initializers from right to left
 	     as we process them here.  So, if we see a data member
 	     initializer after we see a base initializer, that
-	     actually means that the base initializer preceeded the
+	     actually means that the base initializer preceded the
 	     data member initializer.  */
 	  if (warn_reorder && last_base_warned_about != base_init_list)
 	    {
@@ -2109,7 +2109,7 @@
 /* Finish processing a BASE_CLASS with the indicated ACCESS_SPECIFIER.
    Return a TREE_LIST containing the ACCESS_SPECIFIER and the
    BASE_CLASS, or NULL_TREE if an error occurred.  The
-   ACCESSS_SPECIFIER is one of
+   ACCESS_SPECIFIER is one of
    access_{default,public,protected_private}[_virtual]_node.*/
 
 tree 
@@ -2455,7 +2455,7 @@
       /* Remember this function.  In finish_file we'll decide if
 	 we actually need to write this function out.  */
       defer_fn (fn);
-      /* Let the back-end know that this funtion exists.  */
+      /* Let the back-end know that this function exists.  */
       (*debug_hooks->deferred_inline_function) (fn);
       return;
     }
Index: typeck.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/typeck.c,v
retrieving revision 1.374
diff -u -r1.374 typeck.c
--- typeck.c	2001/12/13 01:37:52	1.374
+++ typeck.c	2001/12/16 16:02:57
@@ -324,7 +324,7 @@
 }
 
 /* T1 and T2 are arithmetic or enumeration types.  Return the type
-   that will result from the "usual arithmetic converions" on T1 and
+   that will result from the "usual arithmetic conversions" on T1 and
    T2 as described in [expr].  */
 
 tree
@@ -7010,7 +7010,7 @@
        Casting from an rvalue of type "pointer to data member of X
        of type T1" to the type "pointer to data member of Y of type
        T2" casts away constness if a cast from an rvalue of type
-       "poitner to T1" to the type "pointer to T2" casts away
+       "pointer to T1" to the type "pointer to T2" casts away
        constness.  */
     return casts_away_constness
       (build_pointer_type (TREE_TYPE (TREE_TYPE (t1))),

Index: class.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/class.c,v
retrieving revision 1.423
diff -u -r1.423 class.c
--- class.c	2001/12/13 01:37:47	1.423
+++ class.c	2001/12/16 16:02:51
@@ -1380,9 +1380,9 @@
     }
 }
 
 /* Binfo FROM is within a virtual heirarchy which is being reseated to
    TO. Move primary information from FROM to TO, and recursively traverse
-   into FROM's bases. The heirarchy is dominated by TYPE.  MAPPINGS is an
+   into FROM's bases. The hierarchy is dominated by TYPE.  MAPPINGS is an
    assoc list of binfos that have already been reseated.  */
 
 static void
@@ -1448,7 +1448,7 @@
 }
 
 /* FROM is the canonical binfo for a virtual base. It is being reseated to
-   make TO the canonical binfo, within the heirarchy dominated by TYPE.
+   make TO the canonical binfo, within the hierarchy dominated by TYPE.
    MAPPINGS is an assoc list of binfos that have already been reseated.
    Adjust any non-virtual bases within FROM, and also move any virtual bases
    which are canonical.  This complication arises because selecting primary
@@ -6907,7 +6907,7 @@
 }
 
 /* The type corresponding to BASE_BINFO is a base of the type of BINFO, but
-   from within some heirarchy which is inherited from the type of BINFO.
+   from within some hierarchy which is inherited from the type of BINFO.
    Return BASE_BINFO's equivalent binfo from the hierarchy dominated by
    BINFO.  */
 
@@ -1380,9 +1380,9 @@
 }
 
-/* Binfo FROM is within a virtual heirarchy which is being reseated to
+/* Binfo FROM is within a virtual hierarchy which is being reseated to
    TO. Move primary information from FROM to TO, and recursively traverse
Index: cp-tree.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/cp-tree.h,v
retrieving revision 1.665
diff -u -r1.665 cp-tree.h
--- cp-tree.h	2001/12/14 03:01:56	1.665
+++ cp-tree.h	2001/12/16 16:02:52
@@ -1609,7 +1609,7 @@
 
 /* Nonzero if this binfo has lost its primary base binfo (because that
    is a nearly-empty virtual base that has been taken by some other
-   base in the complete heirarchy.  */
+   base in the complete hierarchy.  */
 #define BINFO_LOST_PRIMARY_P(NODE) TREE_LANG_FLAG_2 (NODE)
 
 /* Nonzero if this binfo is an indirect primary base, i.e. a virtual
@@ -3018,7 +3018,7 @@
   itf_ptrmem_ok = 1 << 2,     /* pointers to member ok (internal use) */
 } instantiate_type_flags;
 
 /* The kind of checking we can do looking in a class heirarchy. */
 typedef enum base_access {
   ba_any = 0,      /* Do not check access, allow an ambiguous base,
 		      prefer a non-virtual base */
@@ -3029,7 +3029,7 @@
   ba_quiet = 4,    /* Do not issue error messages (bit mask).  */
 } base_access;
 
 /* The kind of base we can find, looking in a class heirarchy.
    Values <0 indicate we failed. */
 typedef enum base_kind {
   bk_inaccessible = -3,   /* The base is inaccessible */
@@ -3090,7 +3090,7 @@
   DEDUCE_ORDER
 } unification_kind_t;
 
-/* Macros for operating on a template instantation level node, represented
+/* Macros for operating on a template instantiation level node, represented
    by an EXPR_WITH_FILE_LOCATION.  */
 
 #define TINST_DECL(NODE) EXPR_WFL_NODE (NODE)
@@ -3018,7 +3018,7 @@
 } instantiate_type_flags;
 
-/* The kind of checking we can do looking in a class heirarchy. */
+/* The kind of checking we can do looking in a class hierarchy. */
 typedef enum base_access {
   ba_any = 0,      /* Do not check access, allow an ambiguous base,
@@ -3029,7 +3029,7 @@
 } base_access;
 
-/* The kind of base we can find, looking in a class heirarchy.
+/* The kind of base we can find, looking in a class hierarchy.
    Values <0 indicate we failed. */
 typedef enum base_kind {
-- 
Joseph S. Myers
jsm28@cam.ac.uk


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]